@@ -8,6 +8,11 @@ from .cli import SUBCOMMAND_ARG
 
 
 def run(args):
+    """
+    Execute subcommand.
+    :param args: argparse Namespace
+    :return: None
+    """
     name = getattr(args, SUBCOMMAND_ARG)
     for subcommand in subcommands:
         if name == subcommand.name:
